summaryrefslogtreecommitdiff
path: root/.eslintrc.js
diff options
context:
space:
mode:
authorRuben Bridgewater <ruben@bridgewater.de>2019-01-21 01:22:27 +0100
committerRuben Bridgewater <ruben@bridgewater.de>2019-02-28 18:31:10 +0100
commit9edce1e12a7b69e7986dd15fce18d6e46590161a (patch)
treec5d37d8016a27bab698520ecc51cda4f7ad99d40 /.eslintrc.js
parent7b674697d8005c29391ebaaf562eb4d92ed9b129 (diff)
downloadandroid-node-v8-9edce1e12a7b69e7986dd15fce18d6e46590161a.tar.gz
android-node-v8-9edce1e12a7b69e7986dd15fce18d6e46590161a.tar.bz2
android-node-v8-9edce1e12a7b69e7986dd15fce18d6e46590161a.zip
benchmark,doc,lib,test: capitalize comments
This updates a lot of comments. PR-URL: https://github.com/nodejs/node/pull/26223 Reviewed-By: Rich Trott <rtrott@gmail.com> Reviewed-By: James M Snell <jasnell@gmail.com> Reviewed-By: Vse Mozhet Byt <vsemozhetbyt@gmail.com> Reviewed-By: Anto Aravinth <anto.aravinth.cse@gmail.com>
Diffstat (limited to '.eslintrc.js')
-rw-r--r--.eslintrc.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/.eslintrc.js b/.eslintrc.js
index 9bd8e66123..03dd8e47b8 100644
--- a/.eslintrc.js
+++ b/.eslintrc.js
@@ -60,9 +60,9 @@ module.exports = {
'brace-style': ['error', '1tbs', { allowSingleLine: true }],
'capitalized-comments': ['error', 'always', {
line: {
// Ignore all lines that have less characters than 50 and all lines that
// start with something that looks like a variable name or code.
- ignorePattern: '^.{0,50}$|^ [a-z]+ ?[0-9A-Z_.(/=:[#-]',
+ ignorePattern: '^.{0,40}$|^ [a-z]+ ?[0-9A-Z_.(/=:[#-]|^ std',
ignoreInlineComments: true,
ignoreConsecutiveComments: true,
},
@@ -60,9 +60,9 @@ module.exports = {
'capitalized-comments': ['error', 'always', {
line: {
- // Ignore all lines that have less characters than 50 and all lines that
+ // Ignore all lines that have less characters than 40 and all lines that
// start with something that looks like a variable name or code.